@@ -251,7 +251,6 @@ libxfs_ialloc(
 	xfs_dev_t	rdev,
 	struct cred	*cr,
 	struct fsxattr	*fsx,
-	int		okalloc,
 	xfs_buf_t	**ialloc_context,
 	xfs_inode_t	**ipp)
 {
@@ -264,7 +263,7 @@ libxfs_ialloc(
 	 * Call the space management code to pick
 	 * the on-disk inode to be allocated.
 	 */
-	error = xfs_dialloc(tp, pip ? pip->i_ino : 0, mode, okalloc,
+	error = xfs_dialloc(tp, pip ? pip->i_ino : 0, mode,
 			    ialloc_context, &ino);
 	if (error != 0)
 		return error;
@@ -335,8 +334,8 @@ libxfs_ialloc(
 	case S_IFCHR:
 	case S_IFBLK:
 		ip->i_d.di_format = XFS_DINODE_FMT_DEV;
-		ip->i_df.if_u2.if_rdev = rdev;
 		flags |= XFS_ILOG_DEV;
+		VFS_I(ip)->i_rdev = rdev;
 		break;
 	case S_IFREG:
 	case S_IFDIR:
@@ -368,7 +367,7 @@ libxfs_ialloc(
 		ip->i_d.di_format = XFS_DINODE_FMT_EXTENTS;
 		ip->i_df.if_flags = XFS_IFEXTENTS;
 		ip->i_df.if_bytes = ip->i_df.if_real_bytes = 0;
-		ip->i_df.if_u1.if_extents = NULL;
+		ip->i_df.if_u1.if_root = NULL;
 		break;
 	default:
 		ASSERT(0);
@@ -398,9 +397,10 @@ libxfs_iprint(
 	xfs_inode_t		*ip)
 {
 	struct xfs_icdinode	*dip;
-	xfs_bmbt_rec_host_t	*ep;
-	xfs_extnum_t		i;
-	xfs_extnum_t		nextents;
+	xfs_extnum_t		i = 0;
+	xfs_ifork_t		*ifp;		/* inode fork pointer */
+	struct xfs_iext_cursor	icur;
+	xfs_bmbt_irec_t		rec;
 
 	printf("Inode %lx\n", (unsigned long)ip);
 	printf("    i_ino %llx\n", (unsigned long long)ip->i_ino);
@@ -409,21 +409,18 @@ libxfs_iprint(
 		printf("EXTENTS ");
 	printf("\n");
 	printf("    i_df.if_bytes %d\n", ip->i_df.if_bytes);
-	printf("    i_df.if_u1.if_extents/if_data %lx\n",
-		(unsigned long)ip->i_df.if_u1.if_extents);
+	printf("    i_df.if_u1.if_root/if_data %lx\n",
+		(unsigned long)ip->i_df.if_u1.if_root);
 	if (ip->i_df.if_flags & XFS_IFEXTENTS) {
-		nextents = ip->i_df.if_bytes / (uint)sizeof(*ep);
-		for (ep = ip->i_df.if_u1.if_extents, i = 0; i < nextents;
-								i++, ep++) {
-			xfs_bmbt_irec_t rec;
-
-			xfs_bmbt_get_all(ep, &rec);
+		ifp = XFS_IFORK_PTR(ip, XFS_DATA_FORK);
+		for_each_xfs_iext(ifp, &icur, &rec) {
 			printf("\t%d: startoff %llu, startblock 0x%llx,"
 				" blockcount %llu, state %d\n",
 				i, (unsigned long long)rec.br_startoff,
 				(unsigned long long)rec.br_startblock,
 				(unsigned long long)rec.br_blockcount,
 				(int)rec.br_state);
+			i++;
 		}
 	}
 	printf("    i_df.if_broot %lx\n", (unsigned long)ip->i_df.if_broot);
@@ -469,7 +466,7 @@ libxfs_iflush_int(xfs_inode_t *ip, xfs_buf_t *bp)
 	xfs_dinode_t		*dip;
 	xfs_mount_t		*mp;
 
-	ASSERT(XFS_BUF_FSPRIVATE(bp, void *) != NULL);
+	ASSERT(bp-b_fspriv != NULL);
 	ASSERT(ip->i_d.di_format != XFS_DINODE_FMT_BTREE ||
 		ip->i_d.di_nextents > ip->i_df.if_ext_max);
 	ASSERT(ip->i_d.di_version > 1);
@@ -633,18 +630,6 @@ error0:	/* Cancel bmap, cancel trans */
 	return error;
 }
 
-unsigned int
-libxfs_log2_roundup(unsigned int i)
-{
-	unsigned int	rval;
-
-	for (rval = 0; rval < NBBY * sizeof(i); rval++) {
-		if ((1 << rval) >= i)
-			break;
-	}
-	return rval;
-}
-
 /*
  * Wrapper around call to libxfs_ialloc. Takes care of committing and
  * allocating a new transaction as needed.
@@ -669,7 +654,7 @@ libxfs_inode_alloc(
 
 	ialloc_context = (xfs_buf_t *)0;
 	error = libxfs_ialloc(*tp, pip, mode, nlink, rdev, cr, fsx,
-			   1, &ialloc_context, &ip);
+			   &ialloc_context, &ip);
 	if (error) {
 		*ipp = NULL;
 		return error;
@@ -691,7 +676,7 @@ libxfs_inode_alloc(
 		}
 		xfs_trans_bjoin(*tp, ialloc_context);
 		error = libxfs_ialloc(*tp, pip, mode, nlink, rdev, cr,
-				   fsx, 1, &ialloc_context, &ip);
+				   fsx, &ialloc_context, &ip);
 		if (!ip)
 			error = -ENOSPC;
 		if (error)
